

set -ex



test -L $PREFIX/lib/libcufft.so.11
test -L $PREFIX/lib/libcufftw.so.11
test -L $PREFIX/lib/libcufft.so.11.2.1.3
test -L $PREFIX/lib/libcufftw.so.11.2.1.3
test -L $PREFIX/targets/x86_64-linux/lib/libcufft.so.11
test -L $PREFIX/targets/x86_64-linux/lib/libcufftw.so.11
test -f $PREFIX/targets/x86_64-linux/lib/libcufft.so.11.2.1.3
test -f $PREFIX/targets/x86_64-linux/lib/libcufftw.so.11.2.1.3
bash test-rpath.sh
exit 0
